# coding=utf-8
from ...Classes.Onderdeel.Grasland import Grasland


# Generated with OTLClassCreator. To modify: extend, do not edit
class RaaigrasweideGraslandfase0(Grasland):
    """G0 - Zeer uniform grasland met vrijwel uitsluitend sterk glanzend gras Engels of Italiaans raaigras en/of ruw beemdgras dominant + vogelmuur, straatgras."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RaaigrasweideGraslandfase0'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
